@@ -15,6 +15,7 @@
 #' - `list_resources()`: List all resources deployed under this subscription.
 #' - `list_locations()`: List locations available.
 #' - `get_provider_api_version(provider, type, which=1, stable_only=TRUE)`: Get the current API version for the given resource provider and type. If no resource type is supplied, returns a vector of API versions, one for each resource type for the given provider. If neither provider nor type is supplied, returns the API versions for all resources and providers. Set `stable_only=FALSE` to allow preview APIs to be returned. Set `which` to a number > 1 to return an API other than the most recent.
+#' - `do_operation(...)`: Carry out an operation. See 'Operations' for more details.
 #' - `create_lock(name, level)`: Create a management lock on this subscription (which will propagate to all resources within it).
 #' - `get_lock(name`): Returns a management lock object.
 #' - `delete_lock(name)`: Deletes a management lock object.
@@ -29,6 +30,15 @@
 #' @section Details:
 #' Generally, the easiest way to create a subscription object is via the `get_subscription` or `list_subscriptions` methods of the [az_rm] class. To create a subscription object in isolation, call the `new()` method and supply an Oauth 2.0 token of class [AzureToken], along with the ID of the subscription.
 #'
+#' @section Operations:
+#' The `do_operation()` method allows you to carry out arbitrary operations on the subscription. It takes the following arguments:
+#' - `op`: The operation in question, which will be appended to the URL path of the request.
+#' - `options`: A named list giving the URL query parameters.
+#' - `...`: Other named arguments passed to [call_azure_rm], and then to the appropriate call in httr. In particular, use `body` to supply the body of a PUT, POST or PATCH request, and `api_version` to set the API version.
+#' - `http_verb`: The HTTP verb as a string, one of `GET`, `PUT`, `POST`, `DELETE`, `HEAD` or `PATCH`.
+#'
+#' Consult the Azure documentation for what operations are supported.
+#'
 #' @section Role-based access control:
 #' AzureRMR implements a subset of the full RBAC functionality within Azure Active Directory. You can retrieve role definitions and add and remove role assignments, at the subscription, resource group and resource levels. See [rbac] for more information.
 #'
@@ -185,6 +195,11 @@ public=list(
         lst
     },
 
+    do_operation=function(..., options=list(), http_verb="GET")
+    {
+        private$sub_op(..., options=options, http_verb=http_verb)
+    },
+
     print=function(...)
     {
         cat("<Azure subscription ", self$id, ">\n", sep="")
